@@ -71,7 +71,7 @@ def add_missing_spl_val(dtm, breaks, spl_val):
         else:
             if spl_val is None:
                 spl_val=['missing']
-            elif any([('missing' in i) for i in spl_val]):
+            elif any([('missing' in str(i)) for i in spl_val]):
                 spl_val=spl_val
             else:
                 spl_val=['missing']+spl_val
@@ -281,9 +281,15 @@ def woebin2_init_bin(dtm, init_count_distr, breaks, spl_val):
     if is_numeric_dtype(dtm['value']): # numeric variable
         xvalue = dtm['value'].astype(float)
         # breaks vector & outlier
-        iq = xvalue.quantile([0.25, 0.5, 0.75])
+        iq = xvalue.quantile([0.01, 0.25, 0.75, 0.99])
         iqr = iq[0.75] - iq[0.25]
-        xvalue_rm_outlier = xvalue if iqr == 0 else xvalue[(xvalue >= iq[0.25]-3*iqr) & (xvalue <= iq[0.75]+3*iqr)]
+        if iqr == 0:
+          prob_down = 0.01
+          prob_up = 0.99
+        else:
+          prob_down = 0.25
+          prob_up = 0.75
+        xvalue_rm_outlier = xvalue[(xvalue >= iq[prob_down]-3*iqr) & (xvalue <= iq[prob_up]+3*iqr)]
         # number of initial binning
         n = np.trunc(1/init_count_distr)
         len_uniq_x = len(np.unique(xvalue_rm_outlier))
@@ -291,7 +297,7 @@ def woebin2_init_bin(dtm, init_count_distr, breaks, spl_val):
         # initial breaks
         brk = np.unique(xvalue_rm_outlier) if len_uniq_x < 10 else pretty(min(xvalue_rm_outlier), max(xvalue_rm_outlier), n)
         
-        brk = list(filter(lambda x: x>np.nanmin(xvalue) and x<np.nanmax(xvalue), brk))
+        brk = list(filter(lambda x: x>np.nanmin(xvalue) and x<=np.nanmax(xvalue), brk))
         brk = [float('-inf')] + sorted(brk) + [float('inf')]
         # initial binning datatable
         # cut
@@ -914,7 +920,7 @@ def woebin(dt, y, x=None,
     # init_count_distr range
     if init_count_distr<0.01 or init_count_distr>0.2 or not isinstance(init_count_distr, (float, int)):
         warnings.warn("Incorrect parameter specification; accepted init_count_distr parameter range is 0.01-0.2. Parameter was set to default (0.02).")
-        stop_limit = 0.02
+        init_count_distr = 0.02
     # count_distr_limit
     if count_distr_limit<0.01 or count_distr_limit>0.2 or not isinstance(count_distr_limit, (float, int)):
         warnings.warn("Incorrect parameter specification; accepted count_distr_limit parameter range is 0.01-0.2. Parameter was set to default (0.05).")
